#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-journal
version:              0.8.1
visibility:           public
id:                   monad-journal-0.8.1-Kzh54BOG0B4Bb1P7aGC0P
key:                  monad-journal-0.8.1-Kzh54BOG0B4Bb1P7aGC0P
license:              BSD-3-Clause
maintainer:           Dimitri Sabadie <dimitri.sabadie@gmail.com>
author:               Dimitri Sabadie <dimitri.sabadie@gmail.com>
homepage:             http://github.com/phaazon/monad-journal
synopsis:             Pure logger typeclass and monad transformer
description:
    This package provides a typeclass for logging in
    pure code, or more generally, in any kind of
    context. You can do whatever you want with
    logs, especially get them, clear them or even
    sink them through '\''IO'\'' if you'\''re logging in
    @(MonadIO m) => m@.

category:             Control
abi:                  5eca8f6855677eb30b1450ccfd36ae29
exposed:              True
exposed-modules:
    Control.Monad.Journal Control.Monad.Journal.Class
    Control.Monad.Trans.Journal

import-dirs:          /usr/lib/ghc-8.10.5/site-local/monad-journal-0.8.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/monad-journal-0.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/monad-journal-0.8.1
hs-libraries:         HSmonad-journal-0.8.1-Kzh54BOG0B4Bb1P7aGC0P
depends:
    base-4.14.2.0 monad-control-1.0.2.3-Bi4GOATU8bxGtDgK1rR68J
    mtl-2.2.2 transformers-0.5.6.2
    transformers-base-0.4.5.2-KzHjyAKDkdpHt6juu1Rjxn

haddock-interfaces:
    /usr/share/doc/haskell-monad-journal/html/monad-journal.haddock

haddock-html:         /usr/share/doc/haskell-monad-journal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

